Enum NvFlags Copy item path #[non_exhaustive]
pub enum NvFlags {
BitField,
Counter,
PCR,
NoDA,
System,
Index(NonZeroU32 ),
}Expand description NV index creation flags, as used by the create_nv() function.
Note: The type flags BitField , Counter and PCR are mutually exclusive! If one of these flags is given, then the size of the NV index is implicit defined; otherwise, if no type flag is given, an “ordinary” NV index of application-defined size is created.
This enum is marked as non-exhaustive Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NV index contains an 8-octet value to be used as a bit field and can only be modified with TPM2_NV_SetBits.
NV index contains an 8-octet value that is to be used as a counter and can only be modified with TPM2_NV_Increment.
NV index contains a digestsized value used like a PCR. The Index can only be modified using TPM2_NV_Extend.
NV index is not subject to dictionary attack protections.
Store the NV index in the system-wide directory.
Store the NV index using the contained persistent handle value.
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Compares and returns the maximum of two values.
Read more Compares and returns the minimum of two values.
Read more Restrict a value to a certain interval.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
This method returns an ordering between
self and
other values if one exists.
Read more Tests less than (for
self and
other) and is used by the
< operator.
Read more Tests less than or equal to (for
self and
other) and is used by the
<= operator.
Read more Tests greater than (for
self and
other) and is used by the
>
operator.
Read more Tests greater than or equal to (for
self and
other) and is used by
the
>= operator.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.