Enum SealedData
#[non_exhaustive]pub enum SealedData<'a> {
#[non_exhaustive] Data(&'a [u8]),
#[non_exhaustive] Size(NonZeroUsize),
}Expand description
Data to be sealed, either a non-zero size or some explicit data.
Instances of this struct may be used with the FapiContext::create_seal() function.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
#[non_exhaustive]Data(&'a [u8])
#[non_exhaustive]Size(NonZeroUsize)
Implementations
impl<'a> SealedData<'a>
impl<'a> SealedData<'a>
pub fn from_size(size: usize) -> Result<Self, ErrorCode>
pub fn from_size(size: usize) -> Result<Self, ErrorCode>
Creates a new SealData with the specified non-zero size.
The new sealed object will be created with the specified size and will be initialized by the TPM with random data.
pub fn from_data(data: &'a [u8]) -> Result<Self, ErrorCode>
pub fn from_data(data: &'a [u8]) -> Result<Self, ErrorCode>
Creates a new SealData containing the specified data.
The new sealed object will be created with a size of data.len() and it will be initialized with the given data.
pub fn as_data(&self) -> Option<&[u8]>
pub fn as_data(&self) -> Option<&[u8]>
Returns the “raw” data contained in this SealedData, if applicable; otherwise None.
pub fn as_size(&self) -> Option<NonZeroUsize>
pub fn as_size(&self) -> Option<NonZeroUsize>
Returns the size value contained in this SealedData, if applicable; otherwise None.